package org.jboss.docs.cmp.cd;

import org.jboss.docs.cmp.cd.interfaces.CDCollectionHome;
import org.jboss.docs.cmp.cd.interfaces.CDCollection;
import org.jboss.docs.cmp.cd.interfaces.CD;
import javax.naming.InitialContext;
import javax.rmi.PortableRemoteObject;
import java.util.Hashtable;
import java.util.Properties;
import java.util.Properties;
import java.io.FileInputStream;

/**
 * This is a simple client for the `CD' EJB; it lists (to standard output) all
 * the `CD' instances that have any attribute (artist, title,...) that matches
 * the string supplied. The `main' method allows this class to be executed on
 * the command line.
 */
public class Lookup
{

   public static void main(String[] args)
	{
	   // Check that the command line has specified a string to lookup

   	if (args.length < 1)
	   {
		   System.err.println("Usage: java com.web_tomorrow.cd.Lookup [text]");
   		System.exit(-1);
		}

	   String text = args[0];

   	// Get information about the Bean server from the properties file
	   Properties props = new Properties();
   	Properties sysProps = System.getProperties();
	   try
		{
		   props.load (new FileInputStream ("cd.properties"));
   		sysProps.putAll(props);
   	}
	   catch (Exception e)
		{
		   System.err.println ("Can't read `cd.proprties'");
   		System.exit (-1);
		}
	   System.setProperties (sysProps);

   	// Enclosing the whole process in a single `try' block is not an ideal way
	   // to do exception handling, but I don't want to clutter the program up
   	// with catch blocks
	   try
		{
		   // Get a naming context
   		InitialContext jndiContext = new InitialContext();

   		// Get a reference to a CD Bean
	   	Object ref  = jndiContext.lookup("cd/CDCollection");

		   // Get a reference from this to the Bean's Home interface
   		CDCollectionHome home = (CDCollectionHome)
	   		PortableRemoteObject.narrow (ref, CDCollectionHome.class);

		   CDCollection cdCollection = home.create();

   		CD[] cds = cdCollection.lookupInAnyField(text);
	   	for (int i = 0; i < cds.length; i++)
			{
		   	System.out.println (cds[i].getId() + "\t" + cds[i].getTitle() + "\t" +
					cds[i].getArtist() + "\t" + cds[i].getType());
			}
		}
   	catch(Exception e)
		{
	   	System.out.println(e.toString());
		}
	}

}

