package org.jboss.docs.cmp.cd;

import org.jboss.docs.cmp.cd.interfaces.CDCollectionHome;
import org.jboss.docs.cmp.cd.interfaces.CDCollection;
import org.jboss.docs.cmp.cd.interfaces.CDExistsException;
import org.jboss.docs.cmp.cd.utils.FileLineReader;
import org.jboss.docs.cmp.cd.utils.TokenizerWithBlanks;
import javax.naming.InitialContext;
import javax.rmi.PortableRemoteObject;
import java.util.Hashtable;
import java.util.StringTokenizer;
import java.util.Properties;
import java.io.FileInputStream;

/**
 * Uploads a tab-delimited file of CD data to the database. There is a `main()'
 * method so this class can be run from the command line. `main()' takes one
 * command-line argument: the name of the file to upload. See the documentation
 * for the `uploadFile()' method for details of the file format. Note that the
 * uploading process may be very slow on some machines, especially if you are
 * using an interpreting JVM. Expect to have a cup of coffee if you are
 * uploading more than a hundred CDs.
 * Note that the uploadFile method deletes the existing database before it
 * uploads.
 */
public class Upload
{

   /**
    * Run the upload process from the command line.
    */
   public static void main(String[] args)
	{
	   String filename = "CDs.txt";

   	try
		{
		   uploadFile (filename);
		}
	   catch (java.io.IOException e)
		{
		   System.err.println ("Upload: can't read file `" + filename + "'");
		}
	   catch(Exception e)
      {
		   System.err.println("Upload: " + e.toString());
		}
	   System.out.println ("OK");
	}

   /**
    * This method uploads a database of CDs specified as a text file. The file
    * must contain one line for each CD, with 5 fields on each line. The
    * ordering of the fields is id-title-artist-type-notes. The fields are
    * separated with tabs. Note that a tab on its own must exist as a
    * placeholder for an empty field.
    */
   public static void uploadFile (String filename)
	throws java.io.IOException, javax.naming.NamingException,
		java.rmi.RemoteException, javax.ejb.CreateException
	{
	   // Get a naming context
	   InitialContext jndiContext = new InitialContext();

	   // Get a reference to a CD Bean
	   Object ref  = jndiContext.lookup("cd/CDCollection");

	   // Get a reference from this to the Bean's Home interface
	   CDCollectionHome home = (CDCollectionHome)
		   PortableRemoteObject.narrow (ref, CDCollectionHome.class);

	   CDCollection cdCollection = home.create();

	   cdCollection.deleteAll();

	   FileLineReader flr = new FileLineReader(filename);
	   boolean more = true;
	   int i = 0;
	   do
		{
		   String s = flr.readLine();
		   i++;
		   if (s == null)
			   more = false;
		   else
			{
			   if (s == "") continue;
			   String[] tokens = TokenizerWithBlanks.tokenize(s, '\t');
			   int numTokens = tokens.length;
			   if (numTokens == 5)
				{
				   String id = tokens[0];
				   String title = tokens[1];
   				String artist = tokens[2];
	   			String type = tokens[3];
		   		String notes = tokens[4];
               System.out.println("id="+Integer.valueOf(id));
			   	try
				   {
					   cdCollection.addCd(Integer.valueOf(id), title, artist, type, notes);
					}
   				catch (CDExistsException e)
					{
	   				System.err.println ("uploadFile: duplicate ID on line "
		      			+ i + " (ID is " + id + ")");
            	}
				}
			   else
				   System.err.println ("uploadFile: wrong number of fields on line "
					   + i
					   + " in file `" + filename + "'");
			}
      } while (more);

	} // End of uploadFile()

}
