package org.jboss.docs.cmp.cd.bean;

import org.jboss.docs.cmp.cd.interfaces.CDHome;
import org.jboss.docs.cmp.cd.interfaces.CD;
import org.jboss.docs.cmp.cd.interfaces.CDExistsException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.ejb.EJBException;
import javax.naming.InitialContext;
import javax.rmi.PortableRemoteObject;
import java.rmi.RemoteException;
import java.util.Collection;
import java.util.Vector;

/** This class contains the implementation for the `addCd' method exposed by
 *  this Bean. It includes empty method bodies for the methods prescribed by
 *  the SessionBean interface; these don't need to do anything in this simple
 *  example.
 */
public class CDCollectionBean implements SessionBean
{
   /** Helper function to get the home interface of a specified Bean. This is
    *  used by most of the methods in this class.
    */
   private Object getHome (String path, Class type)
	{
	   try
		{
		   InitialContext jndiContext = new InitialContext();
   	   Object ref = jndiContext.lookup(path);
       	return PortableRemoteObject.narrow(ref,type);
		}
	   catch (Exception e)
      {
         throw new EJBException(e);
      }
   }

   /** Adds a CD to the collection, if possible. If the CD already exists (that
    *  is, there is already an entry in the database with the same `id' field)
    *  then it throws a CDExistsException.
    */
   public void addCd(Integer id, String title, String artist, String type,
			String notes)
	throws CDExistsException, RemoteException
	{
	   CDHome home = (CDHome) getHome("cd/CD", CDHome.class);
	   try
		{
		   CD oldCd = home.findByPrimaryKey(id);
		   Integer dummy = oldCd.getId(); // Force loading of data here
		   // If we get here, the CD is already in the collection
		   throw new CDExistsException();
		}
	   // Because we aren't dealing with air traffic control here, I will assume
	   // that any exception generated from finding whether a CD exists in the
	   // database is an indication that it doesn't, and therefore it's safe to
	   // add it.
	   catch (Exception e)
		{
		   System.out.println("Added CD with id=" + id + ", title=" + title
				+ ", artist=" + artist + ", type=" + type + ", notes=" + notes);
		   try
			{
			   CD cd = home.create(id);
			   cd.setTitle(title);
			   cd.setArtist(artist);
			   cd.setType(type);
			   cd.setNotes(notes);
			   return;
			}
         catch (Exception e2)
         {
            throw new EJBException (e2);
         }
      }
	}

   /**
    * Deletes all CDs from the collection
    */
   public void deleteAll() throws RemoteException
	{
	   CDHome home = (CDHome) getHome("cd/CD", CDHome.class);
	   try
		{
		   Collection all = home.findAll();
		   System.out.println("***found all***");
		   Object[] cds = all.toArray();
		   System.out.println("*** num records = " + cds.length);
		   for (int i = 0; i < cds.length; i++)
         {
			   CD cd = (CD) cds[i];
			   System.out.println("Deleting CD with id=" + cd.getId());
			   try
            {
               cd.remove();
            }
			   catch (RemoveException e)
				{
               System.out.println (e.toString());
            }
			}
		   return;
		}
	   catch (FinderException e)
		{
		   // It's difficult to know what to do here; FinderException does _not_
		   // get thrown if the CD isn't found in the collection: that gets us a
		   // RemoteException instead!
		   System.out.println("Caught FinderException in CDCollection::deleteAll()");
		   return;
		}
	   catch (RemoteException e)
		{
		   // We will get here if the CD database is empty, and also if there is
		   // an error in configuration of the database access descriptor
		   System.out.println(e.toString());
		   return ;
		}
	}

   /**
    * Returns an array of all CDs in the collection
    */
   public CD[] findAll() throws RemoteException, FinderException
	{
	   CDHome home = (CDHome) getHome("cd/CD", CDHome.class);
	   Collection all = home.findAll();
	   return (CD[]) all.toArray(new CD[0]);
	}

   /**
    * Returns an array of all CDs in the collection that have the specified
    * string in any part of any field. This is a very inefficient
    * implementation: it gets the complete list of CDs as obejcts, then
    * interates throw the list checking each field. This whole business could
    * be more efficiently carried out using a big SQL `select' statement, but
    * the whole point of Bean-managed persistence is to avoid explicit database
    * operations.
    */
   public CD[] lookupInAnyField(String _s) throws RemoteException, FinderException
	{
	   String s = _s.toLowerCase();
	   CDHome home = (CDHome) getHome("cd/CD", CDHome.class);
	   Collection all = home.findAll();
	   CD[] cds = (CD[])all.toArray(new CD[0]);

	   Vector v = new Vector();
	   for (int i = 0; i < cds.length; i++)
		{
		   boolean include = false;
		   if (cds[i].getTitle().toLowerCase().indexOf(s) >= 0) include = true;
		   if (cds[i].getArtist().toLowerCase().indexOf(s) >= 0) include = true;
		   if (cds[i].getType().toLowerCase().indexOf(s) >= 0) include = true;
		   if (cds[i].getNotes().toLowerCase().indexOf(s) >= 0) include = true;
		   if (include)
			   v.add(cds[i]);
		}

  	   CD cdOut[] = new CD[v.size()];
      for (int i = 0; i < v.size(); i++)
         cdOut[i] = (CD)v.get(i);
	   return cdOut;
	}

   public void ejbCreate() {}
   public void ejbRemove() {}
   public void ejbActivate() {}
   public void ejbPassivate() {}
   public void setSessionContext(SessionContext sc) {}

}


