package org.jboss.docs.jaas.howto;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;

/** Build the database tables for the DatabaseServerLoginModule. That module
is based on two logical tables:

 Principals(PrincipalID text, Password text)
 Roles(PrincipalID text, Role text, RoleGroup text)

@author Scott_Stark@displayscape.com
@version $Revision: 1.1 $ 
*/
public class BuildDatabase
{

    /** Setup the DatabaseServerLoginModule tables using the Hypersonic
        database. This database needs to be configured under java:/DefaultDS
        which is the default config in the JBoss dist.
    */
    public static void main(String[] args)
    {
        try
        {
            // Load the Hypersonic JDBC driver
            Class.forName("org.hsql.jdbcDriver");
            String jdbcURL = "jdbc:HypersonicSQL:hsql://localhost:1476";
            Connection conn = DriverManager.getConnection(jdbcURL, "sa", "");
            Statement statement = conn.createStatement();
            createPrincipalsTable(statement);
            createRolesTable(statement);
            statement.close();
            conn.close();
        }
        catch(SQLException e)
        {
            e.printStackTrace();
            System.exit(1);
        }
        catch(Exception e)
        {
            e.printStackTrace();
            System.exit(2);
        }
        System.exit(0);
    }

    static void createPrincipalsTable(Statement statement) throws SQLException
    {
        try
        {
            statement.execute("DROP TABLE Principals");
        }
        catch(SQLException e)
        {
            // Ok, assume table does not exist
        }
        boolean result = statement.execute("CREATE TABLE Principals ("
            + "PrincipalID VARCHAR(64) PRIMARY KEY,"
            + "Password VARCHAR(64) )"
        );
        System.out.println("Created Principals table, result="+result);
        result = statement.execute("INSERT INTO Principals VALUES ('scott', 'echoman')");
        System.out.println("INSERT INTO Principals VALUES ('scott', 'echoman'), result="+result);
        result = statement.execute("INSERT INTO Principals VALUES ('stark', 'javaman')");
        System.out.println("INSERT INTO Principals VALUES ('stark', 'javaman'), result="+result);
    }

    static void createRolesTable(Statement statement) throws SQLException
    {
        try
        {
            statement.execute("DROP TABLE Roles");
        }
        catch(SQLException e)
        {
            // Ok, assume table does not exist
        }
        boolean result = statement.execute("CREATE TABLE Roles ("
            + "PrincipalID	VARCHAR(64),"
            + "Role	VARCHAR(64),"
            + "RoleGroup VARCHAR(64) )"
        );
        System.out.println("Created Roles table, result="+result);
        result = statement.execute("INSERT INTO Roles VALUES ('scott', 'Echo', 'Roles')");
        System.out.println("INSERT INTO Roles VALUES ('scott', 'Echo', 'Roles'), result="+result);
        result = statement.execute("INSERT INTO Roles VALUES ('scott', 'caller_scott', 'CallerPrincipal')");
        System.out.println("INSERT INTO Roles VALUES ('scott', 'caller_scott', 'CallerPrincipal'), result="+result);
        result = statement.execute("INSERT INTO Roles VALUES ('stark', 'Java', 'Roles')");
        System.out.println("INSERT INTO Roles VALUES ('stark', 'Java', 'Roles'), result="+result);
        result = statement.execute("INSERT INTO Roles VALUES ('stark', 'Coder', 'Roles')");
        System.out.println("INSERT INTO Roles VALUES ('stark', 'Coder', 'Roles'), result="+result);
        result = statement.execute("INSERT INTO Roles VALUES ('stark', 'caller_stark', 'CallerPrincipal')");
        System.out.println("INSERT INTO Roles VALUES ('stark', 'caller_stark', 'CallerPrincipal'), result="+result);
    }
}
