package org.jboss.docs.javamail;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Hashtable;
import javax.naming.InitialContext;
import javax.rmi.PortableRemoteObject;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse; 


import org.jboss.docs.javamail.Mailer;
import org.jboss.docs.javamail.MailerHome;

/**
 * This Servlet provides a user interface to an Enterprise Java Bean.
 * The example EJB described in the jBoss documentation at
 * http://jboss.org/ sends an e-mail to the given address
 * This servlet will call the Mailer EJB, passing it a the
 * email address. 
 */
public class MailerServlet extends HttpServlet
{
   private MailerHome mailerHome = null;
   
   /** Looks up the MailerHome interface and saves it for use in
    doGet().
    */
   public void init() throws ServletException
   {
      try
      {
         // Get a naming context
         InitialContext jndiContext = new InitialContext();
         // Get a reference to the Interest Bean
         Object ref  = jndiContext.lookup("Mailer");      
         // Get a reference from this to the Bean's Home interface
         mailerHome = (MailerHome) PortableRemoteObject.narrow(ref, MailerHome.class);
      }
      catch(Exception e)
      {
         throw new ServletException("Failed to lookup Mailer", e);
      }
   }

   /**
    */
   public void doPost(HttpServletRequest request, HttpServletResponse response)
      throws ServletException, IOException
   {
      String title = "Servlet interface to Mailer EJB";
      String email = request.getParameter("email");
      // set content type and other response header fields first
      response.setContentType("text/html");
      // then write the data of the response
      PrintWriter out = response.getWriter();
      
      out.println("<HTML><HEAD><TITLE>");
      out.println(title);
      out.println("</TITLE></HEAD><BODY>");
      out.println("<H1>" + title + "</H1>");     
      out.println("<H2>Calling EJB...</H2>");

      try
      {
         // Create an Interest object from the Home interface
         Mailer bean = mailerHome.create();
	 // send the email to the given address
	 bean.sendMail(email);
	 out.println("Mail sent....");
	 out.println("check "+email+" mailbox");
         bean.remove();
      }
      catch(Exception e)
      {
         out.println(e.toString());
      }
      finally
      {
         out.println("</BODY></HTML>");
         out.close();
      }
   }
}
