/*
* JBoss, the OpenSource EJB server
*
* Distributable under LGPL license.
* See terms of license at gnu.org.
*/

package org.jboss.docs.jms.client;

import java.util.Hashtable;

import javax.naming.InitialContext;
import javax.naming.Context;
import javax.naming.NamingException;

import javax.jms.Topic;
/**
 * Simple example how to manually get the InitialContext.
 *
 * May be used when jndi.properties is not available or when the default
 * context is not apropriate
 * @author Peter Antman
 * @version $Revision: 1.1 $
 */

public class ManualJNDI {

   /**
    * Get an initial context for JBoss JNDI (localhost:1099)
    */
   public static Context getInitialContext() throws NamingException{
      
      // Populate with needed propertis
      Hashtable props = new Hashtable();
      props.put(Context.INITIAL_CONTEXT_FACTORY,
		"org.jnp.interfaces.NamingContextFactory");
      props.put(Context.PROVIDER_URL, "localhost:1099");
      props.put("java.naming.rmi.security.manager", "yes");
      props.put(Context.URL_PKG_PREFIXES,  "org.jboss.naming");
      
      // Get initial context with given properties
      return new InitialContext(props);
      
   } 
   
   /**
    * Test looking up a known topic, if no errors JNDI works.
    */
   public static void main(String[] args) {
      try {
	 // Get the manually configured initial context
	 Context context = getInitialContext();
	 
	 // Do the lookup
	 Topic t = (Topic)context.lookup("topic/testTopic");
	 System.out.println("Looing up topic/testTopic worked fine");
      }catch (Exception ex) {
	 System.err.println("Could not lookup topic/testTopic");
	 ex.printStackTrace();
      }
   }
   
} // ManualJNDI
